fedora

package
v0.9.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 14, 2025 License: Apache-2.0 Imports: 28 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Create

func Create(ctx *mc.ContextArgs, args *FedoraArgs) (err error)

Create orchestrate 2 stacks: If spot is enable it will run best spot option to get the best option to spin the machine Then it will run the stack for windows dedicated host

func Destroy

func Destroy(c *mc.ContextArgs) (err error)

Will destroy resources related to machine

Types

type FedoraArgs added in v0.9.1

type FedoraArgs struct {
	Prefix         string
	Version        string
	Arch           string
	ComputeRequest *cr.ComputeRequestArgs
	Spot           *spotTypes.SpotArgs
	Airgap         bool
	// If timeout is set a severless scheduled task will be created to self destroy the resources
	Timeout string
}

Jump to