Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Create ¶
func Create(ctx *mc.ContextArgs, args *FedoraArgs) (err error)
Create orchestrate 2 stacks: If spot is enable it will run best spot option to get the best option to spin the machine Then it will run the stack for windows dedicated host
func Destroy ¶
func Destroy(c *mc.ContextArgs) (err error)
Will destroy resources related to machine
Types ¶
Click to show internal directories.
Click to hide internal directories.