Documentation
¶
Index ¶
- func Create(mCtxArgs *mc.ContextArgs, r *MacPoolRequestArgs) error
- func Destroy(mCtxArgs *mc.ContextArgs) error
- func HouseKeeper(mCtxArgs *mc.ContextArgs, r *MacPoolRequestArgs) error
- func Release(mCtxArgs *mc.ContextArgs, hostID string) error
- func Request(mCtxArgs *mc.ContextArgs, r *RequestMachineArgs) error
- type MacPoolRequestArgs
- type ReleaseMachineArgs
- type RequestMachineArgs
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Create ¶
func Create(mCtxArgs *mc.ContextArgs, r *MacPoolRequestArgs) error
Even if we want to destroy the pool we will set params to max size 0
func Destroy ¶
func Destroy(mCtxArgs *mc.ContextArgs) error
TODO decide how to destroy machines in the pool as they may need to wait to reach 24 hours
func HouseKeeper ¶
func HouseKeeper(mCtxArgs *mc.ContextArgs, r *MacPoolRequestArgs) error
House keeper is the function executed serverless to check if is there any machine non locked which had been running more than 24h. It should check if capacity allows to remove the machine
func Request ¶
func Request(mCtxArgs *mc.ContextArgs, r *RequestMachineArgs) error
Types ¶
type MacPoolRequestArgs ¶
type MacPoolRequestArgs struct {
// Prefix for the resources related to mac
// this is relevant in case of an orchestration with multiple
// macs on the same stack
Prefix string
// Pool specs
PoolName string
Architecture string
OSVersion string
// Pool params
// Capacity is the number of machines in the pool ready to process a workload
// at any given time
OfferedCapacity int
// Max is the max capacity of machines in the pool. Even if capacity is not meet if number of machines
// are equal to max it will not create more machines
MaxSize int
// If fixed location is set machines only created on current region, in case no capacity it will not
// create on different regions
FixedLocation bool
}
type ReleaseMachineArgs ¶
type ReleaseMachineArgs struct {
}
Click to show internal directories.
Click to hide internal directories.