Documentation
¶
Index ¶
Constants ¶
const ( StackDedicatedHost = "stackDedicatedHost" StackMacMachine = "stackMacMachine" )
Variables ¶
This section is empty.
Functions ¶
func IsMachineLocked ¶
func IsMachineLocked(h *mac.HostInformation) (bool, error)
func PickHost ¶
func PickHost(prefix string, his []*mac.HostInformation) (*mac.HostInformation, error)
We will get a list of hosts from the pool ordered by allocation time We will apply several rules on them to pick the right one - TODO Remove those with allocation time > 24 h as they may destroyed - if none left use them again - if more available pick in order the first without lock
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.